@@ -9,13 +9,12 @@ use strict;
 use Mouse;
 use Crypt::OpenSSL::RSA;
 use Crypt::OpenSSL::X509;
-use Data::Dumper;
 use HTML::Template;
 use MIME::Base64;
 use Safe;
 use Encode;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.3';
 
 my $dataStart = tell(DATA);
 
@@ -24,7 +23,7 @@ my $dataStart = tell(DATA);
 # SAML 2 description.
 # @return string
 sub serviceToXML {
-    my ( $self, $conf ) = @_;
+    my ( $self, $conf, $type ) = @_;
 
     seek DATA, $dataStart, 0;
     my $s = join '', <DATA>;
@@ -42,10 +41,23 @@ sub serviceToXML {
       samlOrganizationURL
     );
 
+    if ( $type and $type eq 'idp' ) {
+        $template->param( 'hideSPMetadata', 1 );
+    }
+
+    if ( $type and $type eq 'sp' ) {
+        $template->param( 'hideIDPMetadata', 1 );
+    }
+
     foreach (@param_auto) {
         $template->param( $_, $self->getValue( $_, $conf ) );
     }
 
+    # When asked to provide only IDP metadata, take into account EntityID override
+    if ( $type eq "idp" and $conf->{samlOverrideIDPEntityID} ) {
+        $template->param( 'samlEntityID', $conf->{samlOverrideIDPEntityID} );
+    }
+
     # Boolean parameters
     my @param_boolean = qw(
       samlSPSSODescriptorAuthnRequestsSigned
@@ -196,6 +208,7 @@ __DATA__
     xmlns:ds="http://www.w3.org/2000/09/xmldsig#"
     entityID="<TMPL_VAR NAME="samlEntityID">">
 
+  <TMPL_UNLESS NAME="hideIDPMetadata">
   <IDPSSODescriptor
       WantAuthnRequestsSigned="<TMPL_VAR NAME="samlIDPSSODescriptorWantAuthnRequestsSigned">"
       protocolSupportEnumeration="urn:oasis:names:tc:SAML:2.0:protocol">
@@ -254,7 +267,9 @@ __DATA__
       ResponseLocation="<TMPL_VAR NAME="samlIDPSSODescriptorSingleSignOnServiceHTTPArtifactResponseLocation">"
       </TMPL_IF>/>
   </IDPSSODescriptor>
+  </TMPL_UNLESS>
 
+  <TMPL_UNLESS NAME="hideSPMetadata">
   <SPSSODescriptor
       AuthnRequestsSigned="<TMPL_VAR NAME="samlSPSSODescriptorAuthnRequestsSigned">"
       WantAssertionsSigned="<TMPL_VAR NAME="samlSPSSODescriptorWantAssertionsSigned">"
@@ -306,7 +321,9 @@ __DATA__
       Binding="<TMPL_VAR NAME="samlSPSSODescriptorAssertionConsumerServiceHTTPPostBinding">"
       Location="<TMPL_VAR NAME="samlSPSSODescriptorAssertionConsumerServiceHTTPPostLocation">" />
   </SPSSODescriptor>
+  </TMPL_UNLESS>
 
+  <TMPL_UNLESS NAME="hideIDPMetadata">
   <AttributeAuthorityDescriptor
     protocolSupportEnumeration="urn:oasis:names:tc:SAML:2.0:protocol">
     <KeyDescriptor use="signing">
@@ -329,7 +346,8 @@ __DATA__
     <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:entity</NameIDFormat>
     <NameIDFormat>urn:oasis:names:tc:SAML:2.0:nameid-format:transient</NameIDFormat>
   </AttributeAuthorityDescriptor>
-  
+  </TMPL_UNLESS>
+
   <Organization>
     <OrganizationName xml:lang="en"><TMPL_VAR NAME="samlOrganizationName"></OrganizationName>
     <OrganizationDisplayName xml:lang="en"><TMPL_VAR NAME="samlOrganizationDisplayName"></OrganizationDisplayName>
