@@ -6,11 +6,27 @@
 
 package Lemonldap::NG::Common::Session;
 
-our $VERSION = '1.9.991_01';
+our $VERSION = '2.0.0';
 
-use Mouse;
 use Lemonldap::NG::Common::Apache::Session;
 
+# Workaround for another ModPerl/Mouse issue...
+BEGIN {
+    require Mouse;
+    no warnings;
+    my $v =
+      $Mouse::VERSION
+      ? sprintf( "%d.%03d%03d", ( $Mouse::VERSION =~ /(\d+)/g ) )
+      : 0;
+    if ( $v < 2.005001 and $Lemonldap::NG::Handler::Apache2::Main::VERSION ) {
+        require Moose;
+        Moose->import();
+    }
+    else {
+        Mouse->import();
+    }
+}
+
 has 'id' => (
     is  => 'rw',
     isa => 'Str|Undef',
@@ -111,8 +127,12 @@ sub BUILD {
 
     if ( $self->{info} ) {
         foreach ( keys %{ $self->{info} } ) {
-            $data->{$_} = $self->{info}->{$_}
-              if ( defined $self->{info}->{$_} );
+            if ( defined $self->{info}->{$_} ) {
+                $data->{$_} = $self->{info}->{$_};
+            }
+            else {
+                delete $data->{$_};
+            }
         }
         delete $self->{info};
     }
